%% apply_call
%    callback for apply button, save the settings but do not close
%    figure.
% inputs:
%   object:Settings - current object
%   src - source of the callback calling
%   event - event that triggered the callback
% outputs:
%   none
% Author: Colin Eles elesc@mcmaster.ca
% Organization: McMaster Centre for Software Certification
function err = apply_call(object,src,event)
object.save;
end

